# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"getcatdict": "00_utils.ipynb",
         "store_bson": "00_utils.ipynb",
         "load_bson": "00_utils.ipynb",
         "generate_files_embedprojector_for_comparision": "00_utils.ipynb",
         "JSONizerWithBool": "01_extract.ipynb",
         "get_metadict_skeleton": "02_transfer.ipynb"}

modules = ["utils.py",
           "extract.py",
           "transfer.py"]

doc_url = "https://manikyabard.github.io/transfertab/"

git_url = "https://github.com/manikyabard/transfertab/tree/master/"

def custom_doc_links(name): return None
